@@ -10,11 +10,10 @@ class HTTPClient(object):
         self.id = 0
         self.requests = {}
 
-
-    def get_url(self, url, method='GET', headers={}, cb=None, cbargs=None, eb=None, ebargs=None, body=""):
+    def get_url(self, url, method='GET', headers={}, cb=None, cbargs=(), eb=None, ebargs=(), body="", timeout=None):
         self.id += 1
         path, host, port = self.__parse_url(url)
-        self.requests[self.id] = URLRequest(self.id, path, host, port, method, headers, cb, cbargs, eb, ebargs, body=body)
+        self.requests[self.id] = URLRequest(self.id, path, host, port, method, headers, cb, cbargs, eb, ebargs, body, timeout=timeout)
         self.client.get_connection(host, port, self.__conn_cb, [self.id], self.__conn_timeout_cb, [self.id])
     
     def __conn_timeout_cb(self, id):
@@ -61,7 +60,7 @@ class HTTPClient(object):
         return path, hostname, port
         
 class URLRequest(object):
-    def __init__(self, id, path, host, port, method, headers, cb, cbargs, eb, ebargs, body):
+    def __init__(self, id, path, host, port, method, headers, cb, cbargs, eb, ebargs, body, timeout=None):
         self.id = id
         self.cb = cb
         self.path = path
@@ -74,12 +73,21 @@ class URLRequest(object):
         self.eb = eb
         self.ebargs = ebargs
         self.body = body
+        self.timeout = event.event(self.failure)
+        if timeout:
+            self.timeout.add(timeout)
+        self.failed = False
         
     def success(self, response):
-        if self.cb:
-            args = []
-            if self.cbargs:
-                args = self.cbargs
-            self.cb(response, *args)
-        
+        if not self.failed:
+            self.timeout.delete()
+            if self.cb:
+                args = []
+                if self.cbargs:
+                    args = self.cbargs
+                self.cb(response, *args)
         
+    def failure(self, *args, **kwargs):
+        self.failed = True
+        if self.eb:
+            self.eb(*self.ebargs)
