@@ -9,6 +9,10 @@ def main(**kwargs):
     server = SocketDaemon(kwargs['domain'], kwargs['port'], cb=EchoConnection)
     server.start()
 
+def http(**kwargs):
+    server = SocketDaemon(kwargs['domain'], kwargs['port'],cb=EchoHTTP)
+    server.start()
+
 class LocalEchoHTTPClient(object):
     def __init__(self, conn):
         self.conn = conn
@@ -34,6 +38,16 @@ class EchoConnection(object):
     def line_received(self, data):
         #self.conn.write("S: " + data + '\r\n')
         print data
+        self.conn.set_rmode_close(self.line_received)
+
+class EchoHTTP(object):
+    def __init__(self, conn):
+        self.conn = conn
+        self.conn.set_rmode_delimiter('\r\n\r\n', self.line_received)
+
+    def line_received(self, data):
+        print data
+        self.conn.set_rmode_close(self.line_received)
 
 class LengthConnection(object):
     def __init__(self, conn):
